"use strict";
/**
 * Firebase Backend Service
 * Handles authentication, licensing, and cloud memory sync
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || (function () {
    var ownKeys = function(o) {
        ownKeys = Object.getOwnPropertyNames || function (o) {
            var ar = [];
            for (var k in o) if (Object.prototype.hasOwnProperty.call(o, k)) ar[ar.length] = k;
            return ar;
        };
        return ownKeys(o);
    };
    return function (mod) {
        if (mod && mod.__esModule) return mod;
        var result = {};
        if (mod != null) for (var k = ownKeys(mod), i = 0; i < k.length; i++) if (k[i] !== "default") __createBinding(result, mod, k[i]);
        __setModuleDefault(result, mod);
        return result;
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
exports.firebaseService = exports.FirebaseService = void 0;
const crypto = __importStar(require("crypto"));
class FirebaseService {
    constructor() {
        this.baseUrl = process.env.CODECONTEXT_API_URL || 'https://us-central1-codecontext-memory-pro.cloudfunctions.net';
    }
    async authenticate(email, licenseKey) {
        const response = await this.makeRequest('/validateLicense', {
            method: 'POST',
            body: {
                email,
                licenseKey,
                version: this.getCliVersion(),
                platform: process.platform
            }
        });
        if (!response.valid) {
            throw new Error(response.error || 'Invalid license key');
        }
        this.apiKey = response.license.apiKey;
        return response.license;
    }
    async checkLicenseAvailability() {
        const response = await this.makeRequest('/licenses/availability', {
            method: 'GET'
        });
        return response.stats;
    }
    async purchaseLicense(email, paymentToken) {
        const response = await this.makeRequest('/licenses/purchase', {
            method: 'POST',
            body: {
                email,
                paymentToken,
                tier: 'early_adopter' // Will auto-upgrade to standard after 10k
            }
        });
        if (!response.success) {
            throw new Error(response.error || 'Purchase failed');
        }
        return {
            licenseKey: response.licenseKey,
            license: response.license
        };
    }
    async syncMemoryToCloud(projectId, memoryData) {
        if (!this.apiKey) {
            throw new Error('Authentication required for cloud sync');
        }
        await this.makeRequest('/memory/sync', {
            method: 'POST',
            headers: {
                'Authorization': `Bearer ${this.apiKey}`
            },
            body: {
                projectId,
                memoryData: this.encryptMemoryData(memoryData),
                timestamp: new Date().toISOString()
            }
        });
    }
    async getCloudMemory(projectId) {
        if (!this.apiKey) {
            throw new Error('Authentication required for cloud sync');
        }
        const response = await this.makeRequest(`/memory/projects/${projectId}`, {
            method: 'GET',
            headers: {
                'Authorization': `Bearer ${this.apiKey}`
            }
        });
        return this.decryptMemoryData(response.memoryData);
    }
    async validateExecution(code, language, projectContext) {
        if (!this.apiKey) {
            throw new Error('Authentication required for execution engine');
        }
        const response = await this.makeRequest('/execution/validate', {
            method: 'POST',
            headers: {
                'Authorization': `Bearer ${this.apiKey}`
            },
            body: {
                code: this.encryptCode(code),
                language,
                projectContext: this.encryptMemoryData(projectContext),
                requestId: crypto.randomUUID()
            }
        });
        return {
            success: response.success,
            output: response.output,
            error: response.error,
            executionTime: response.executionTime,
            memoryUsed: response.memoryUsed,
            securityScore: response.securityScore
        };
    }
    async validateUsage(operation, email, licenseKey) {
        const response = await this.makeRequest('/validateUsage', {
            method: 'POST',
            body: {
                licenseKey,
                operation,
                email
            }
        });
        if (!response.success) {
            throw new Error(response.error || 'Usage validation failed');
        }
        return {
            success: response.success,
            remaining: response.remaining,
            limit: response.limit,
            tier: response.tier
        };
    }
    async reportUsage(action, metadata) {
        if (!this.apiKey)
            return; // Silent fail for usage tracking
        try {
            await this.makeRequest('/usage/track', {
                method: 'POST',
                headers: {
                    'Authorization': `Bearer ${this.apiKey}`
                },
                body: {
                    action,
                    metadata,
                    timestamp: new Date().toISOString(),
                    version: this.getCliVersion()
                }
            });
        }
        catch (error) {
            // Silent fail - don't break CLI for usage tracking
        }
    }
    async makeRequest(endpoint, options) {
        const url = `${this.baseUrl}${endpoint}`;
        const headers = {
            'Content-Type': 'application/json',
            'User-Agent': `CodeContext-CLI/${this.getCliVersion()}`,
            ...options.headers
        };
        const response = await fetch(url, {
            method: options.method,
            headers,
            body: options.body ? JSON.stringify(options.body) : undefined
        });
        if (!response.ok) {
            const error = await response.text();
            throw new Error(`API Error: ${response.status} - ${error}`);
        }
        return response.json();
    }
    encryptMemoryData(data) {
        // Encrypt sensitive memory data before sending to cloud
        const key = this.apiKey || 'default-key';
        const keyBuffer = crypto.createHash('sha256').update(key).digest();
        const iv = crypto.randomBytes(16);
        const cipher = crypto.createCipheriv('aes-256-cbc', keyBuffer, iv);
        let encrypted = cipher.update(JSON.stringify(data), 'utf8', 'hex');
        encrypted += cipher.final('hex');
        return iv.toString('hex') + ':' + encrypted;
    }
    decryptMemoryData(encryptedData) {
        // Decrypt memory data from cloud
        const key = this.apiKey || 'default-key';
        const keyBuffer = crypto.createHash('sha256').update(key).digest();
        const [ivHex, encrypted] = encryptedData.split(':');
        const iv = Buffer.from(ivHex, 'hex');
        const decipher = crypto.createDecipheriv('aes-256-cbc', keyBuffer, iv);
        let decrypted = decipher.update(encrypted, 'hex', 'utf8');
        decrypted += decipher.final('utf8');
        return JSON.parse(decrypted);
    }
    encryptCode(code) {
        // Encrypt code before sending for execution
        const key = this.apiKey || 'default-key';
        const keyBuffer = crypto.createHash('sha256').update(key).digest();
        const iv = crypto.randomBytes(16);
        const cipher = crypto.createCipheriv('aes-256-cbc', keyBuffer, iv);
        let encrypted = cipher.update(code, 'utf8', 'hex');
        encrypted += cipher.final('hex');
        return iv.toString('hex') + ':' + encrypted;
    }
    getCliVersion() {
        try {
            const packageJson = require('../../package.json');
            return packageJson.version;
        }
        catch {
            return '1.0.0';
        }
    }
}
exports.FirebaseService = FirebaseService;
exports.firebaseService = new FirebaseService();
//# sourceMappingURL=FirebaseService.js.map